@@ -1,8 +1,7 @@
 package Net::Google::Analytics;
-{
-  $Net::Google::Analytics::VERSION = '3.02';
-}
+$Net::Google::Analytics::VERSION = '3.03';
 use strict;
+use warnings;
 
 # ABSTRACT: Simple interface to the Google Analytics Core Reporting API
 
@@ -66,7 +65,10 @@ sub new_request {
 sub _uri {
     my ($self, $req, $start_index, $max_results) = @_;
 
-    my $uri = URI->new('https://www.googleapis.com/analytics/v3/data/ga');
+    my $service = $req->realtime ? 'realtime' : 'ga';
+    my $uri = URI->new(
+        "https://www.googleapis.com/analytics/v3/data/$service"
+    );
     my @params;
     push(@params, 'start-index' => $start_index) if defined($start_index);
     push(@params, 'max-results' => $max_results) if defined($max_results);
@@ -174,13 +176,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Google::Analytics - Simple interface to the Google Analytics Core Reporting API
 
 =head1 VERSION
 
-version 3.02
+version 3.03
 
 =head1 SYNOPSIS
 
@@ -360,7 +364,7 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Nick Wellnhofer.
+This software is copyright (c) 2015 by Nick Wellnhofer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
