@@ -1,13 +1,13 @@
 package Net::Google::Analytics::Request;
-{
-  $Net::Google::Analytics::Request::VERSION = '3.02';
-}
+$Net::Google::Analytics::Request::VERSION = '3.03';
 use strict;
+use warnings;
 
 # ABSTRACT: Google Analytics API request
 
 use Class::XSAccessor
     accessors => [ qw(
+        realtime
         ids
         start_date end_date
         metrics dimensions
@@ -39,7 +39,13 @@ my @param_map = (
 sub _params {
     my $self = shift;
 
-    for my $name (qw(ids metrics start_date end_date)) {
+    my @required = qw(ids metrics);
+
+    if (!$self->{realtime}) {
+        push(@required, qw(start_date end_date));
+    }
+
+    for my $name (@required) {
         my $value = $self->{$name};
         die("parameter $name is empty")
             if !defined($value) || $value eq '';
@@ -64,13 +70,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Google::Analytics::Request - Google Analytics API request
 
 =head1 VERSION
 
-version 3.02
+version 3.03
 
 =head1 SYNOPSIS
 
@@ -111,17 +119,21 @@ L<API reference|http://code.google.com/apis/analytics/docs/gdata/v3/reference.ht
 for a description of the request parameters. The provided parameter values must
 not be URL encoded.
 
+=head2 realtime
+
+Set this parameter to use the Real Time Reporting API.
+
 =head2 ids
 
 Required
 
 =head2 start_date
 
-Required
+Required for non-realtime requests
 
 =head2 end_date
 
-Required
+Required for non-realtime requests
 
 =head2 metrics
 
@@ -153,7 +165,7 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Nick Wellnhofer.
+This software is copyright (c) 2015 by Nick Wellnhofer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
