@@ -1,8 +1,7 @@
 package Net::Google::Analytics::Response;
-{
-  $Net::Google::Analytics::Response::VERSION = '3.02';
-}
+$Net::Google::Analytics::Response::VERSION = '3.03';
 use strict;
+use warnings;
 
 # ABSTRACT: Google Analytics API response
 
@@ -64,7 +63,7 @@ sub _parse_json {
 sub _parse_column_name {
     my $name = shift;
 
-    my ($res) = $name =~ /^ga:(\w{1,64})\z/
+    my ($res) = $name =~ /^(?:ga|rt):(\w{1,64})\z/
         or die("invalid column name: $name");
 
     # convert camel case
@@ -180,13 +179,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::Google::Analytics::Response - Google Analytics API response
 
 =head1 VERSION
 
-version 3.02
+version 3.03
 
 =head1 SYNOPSIS
 
@@ -326,7 +327,7 @@ Nick Wellnhofer <wellnhofer@aevum.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Nick Wellnhofer.
+This software is copyright (c) 2015 by Nick Wellnhofer.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
